@@ -6,6 +6,7 @@ import yaml
 from dateutil import parser
 from datetime import datetime
 from typing import Dict, Optional
+from pathlib import Path
 
 from .constants import (
     API_KEY_CONFIG_KEY,
@@ -170,7 +171,8 @@ class ConfigHandler:
     def config_dir(self) -> str:
         """Retrieve Transform config_dir from $TFD_CONFIG_DIR, default config dir is ~/.transform"""
         config_dir_env = os.getenv("TFD_CONFIG_DIR")
-        return config_dir_env if config_dir_env else f"{os.getenv('HOME')}/.transform"
+
+        return config_dir_env if config_dir_env else f"{str(Path.home())}/.transform"
 
     @property
     def config_file_path(self) -> str:
