@@ -124,7 +124,7 @@ class BackendInterface(BaseInterface):  # noqa: D
                 commit=commit,
                 config_dir=config_dir,
                 is_current=is_current,
-                api_url=self.rest_api_url
+                api_url=self.rest_api_url,
             )
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
@@ -720,6 +720,33 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["dimensions"]
         ]
 
+    def get_all_data_warehouse_validation_issues(self, model_key: Optional[ModelKey] = None) -> List[str]:
+        """Get a list of all data warehouse validation issues"""
+        query = gql(
+            """
+            query ValidateModel($modelKey: ModelKeyInput) {
+                validations(modelKey: $modelKey) {
+                    allIssues
+                }
+            }
+            """
+        )
+
+        # TODO: If this starts timing out we should move to a createMqlQuery approach
+        return self.execute(
+            query,
+            variable_values={
+                "modelKey": {
+                    "organization": model_key.organization_id,
+                    "repo": model_key.repository,
+                    "branch": model_key.branch,
+                    "commit": model_key.commit,
+                }
+                if model_key
+                else None
+            },
+        )["validations"]["allIssues"]
+
     def create_query(  # noqa: D
         self,
         metrics: List[str],
