@@ -5,6 +5,8 @@ from typing import Dict, List, Optional, Tuple
 
 from .auth import TransformAuth
 from .models import (
+    INF,
+    NEGATIVE_ONE,
     CacheMode,
     Dimension,
     HealthReportStatus,
@@ -56,7 +58,7 @@ class MQLClient:
             TimeGranularity(time_granularity) if time_granularity else None,
             PercentChange(time_comparison) if time_comparison else None,
             order,
-            limit,
+            None if limit in [INF, NEGATIVE_ONE, int(NEGATIVE_ONE)] else limit,
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
             allow_dynamic_cache,
@@ -95,7 +97,7 @@ class MQLClient:
             TimeGranularity(time_granularity) if time_granularity else None,
             PercentChange(time_comparison) if time_comparison else None,
             order,
-            limit,
+            None if limit in [INF, NEGATIVE_ONE, int(NEGATIVE_ONE)] else limit,
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
             allow_dynamic_cache,
@@ -125,8 +127,8 @@ class MQLClient:
     def create_materialization(  # noqa: D
         self,
         materialization_name: str,
-        start_time: Optional[str],
-        end_time: Optional[str],
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
         model_key_id: Optional[int] = None,
         output_table: Optional[str] = None,
         force: bool = False,
@@ -144,8 +146,8 @@ class MQLClient:
     def materialize(  # noqa: D
         self,
         materialization_name: str,
-        start_time: Optional[str],
-        end_time: Optional[str],
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
         model_key_id: Optional[int] = None,
         output_table: Optional[str] = None,
         force: bool = False,
@@ -165,8 +167,8 @@ class MQLClient:
     def drop_materialization(  # noqa: D
         self,
         materialization_name: str,
-        start_time: Optional[str],
-        end_time: Optional[str],
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
         model_key_id: Optional[int] = None,
     ) -> MqlQueryStatusResp:
         """Implements drop materialization mutation in MQL/GQL. Can be very expensive if a large time range is provided.
@@ -280,3 +282,9 @@ class MQLClient:
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         dimensions = self.context.mql_client.get_dimensions(model_key)
         return {dim.name: dim for dim in dimensions}
+
+    def validate_model_against_data_warehouse(self, model_key_id: Optional[int] = None) -> List[str]:
+        """Retrieves a list of any and all data warehosue validation issues with the model."""
+        model_key = self.get_model_key(model_key_id) if model_key_id else None
+        issues = self.context.mql_client.get_all_data_warehouse_validation_issues(model_key)
+        return issues
